@@ -4,29 +4,13 @@ import pkg_resources
 from distutils import log
 # turn off logging temporarily so stdout can work:
 log.set_threshold(6)
-import pydoc, tokenize
+from wikir import split_doc_from_module
 from docutils.parsers.rst import directives
 try:
     from cStringIO import StringIO
 except ImportError:
     from StringIO import StringIO
 
-def split_doc_from_module(modfile):
-    docstring = None
-    f = open(modfile,'r')
-    for toknum, tokval, _, _, _ in tokenize.generate_tokens(lambda: f.readline()):
-        if toknum == tokenize.STRING:
-            docstring = tokval
-            break
-        if toknum not in (tokenize.NL, tokenize.COMMENT):
-            # we went too far
-            break
-    if docstring is None:
-        raise ValueError("could not find docstring in %s" % modfile)
-    docstring = docstring[3:]
-    docstring = docstring[:-3]
-    return pydoc.splitdoc(docstring)
-
 class publish_wiki(Command):
     description = "Publish RST to wiki"
     user_options = [
